@@ -25,3 +25,7 @@ class AlexapyLoginError(AlexapyError):
 
 class AlexapyTooManyRequestsError(AlexapyError):
     """Define an error related to too many requests."""
+
+
+class AlexapyLoginCloseRequested(AlexapyError):
+    """Define an error related to requesting access to API after requested close."""
